@@ -74,7 +74,9 @@ class TestForcePlot(WidgetTest):
         x_data = np.arange(5)
         pos_y_data = [(np.arange(5) - 1, np.arange(5))]
         neg_y_data = [(np.arange(5), np.arange(5) + 1)]
-        self.plot.set_data(x_data, pos_y_data, neg_y_data, self.housing)
+        labels = [a.name for a in self.housing.domain.attributes]
+        self.plot.set_data(x_data, pos_y_data, neg_y_data, "", "",
+                           labels, labels, self.housing)
 
         # select after data is sent
         view_box.mouseDragEvent(event)
@@ -95,49 +97,6 @@ class TestForcePlot(WidgetTest):
         selection_handler.assert_called_once()
         self.assertEqual(len(selection_handler.call_args[0][0]), 0)
 
-    @patch.object(QToolTip, "showText")
-    def test_tooltip(self, show_text: Mock):
-        event = Mock()
-        point = self.plot.getViewBox().mapViewToScene(QPointF(1, 2))
-        event.scenePos.return_value = point
-        self.plot.help_event(event)
-        self.assertIsNone(show_text.call_args)
-
-        x_data = np.arange(5)
-        pos_y_data = [(np.arange(5) - 1, np.arange(5))]
-        neg_y_data = [(np.arange(5), np.arange(5) + 1)]
-        data = self.housing[:5, :2]
-        self.plot.set_data(x_data, pos_y_data, neg_y_data, data)
-
-        event = Mock()
-        point = self.plot.getViewBox().mapViewToScene(QPointF(1, 2))
-        event.scenePos.return_value = point
-        self.plot.help_event(event)
-        self.assertEqual(
-            show_text.call_args[0][1],
-            "<br/><br/><b>Features</b>:<br/>CRIM = 0.02731<br/>ZN = 0.0"
-        )
-
-        self.plot.set_data(x_data, pos_y_data, neg_y_data, data)
-
-        event = Mock()
-        point = self.plot.getViewBox().mapViewToScene(QPointF(1, 2))
-        event.scenePos.return_value = point
-        self.plot.help_event(event)
-        self.assertEqual(
-            show_text.call_args[0][1],
-            "<br/><br/><b>Features</b>:<br/>CRIM = 0.02731<br/>ZN = 0.0"
-        )
-
-    def test_instance_tooltip(self):
-        domain = self.housing.domain
-        instance = self.housing[0]
-        text = "<b>Class</b>:<br/>MEDV = 24.0<br/><br/><b>Features</b>:<br/>" \
-               "CRIM = 0.00632<br/>ZN = 18.0<br/>INDUS = 2.31<br/>CHAS = 0" \
-               "<br/>NOX = 0.5380<br/>RM = 6.575<br/>AGE = 65.2<br/>" \
-               "DIS = 4.0900<br/>RAD = 1<br/>... and 4 others"
-        self.assertEqual(self.plot._instance_tooltip(domain, instance), text)
-
 
 class TestOWExplainPredictions(WidgetTest):
     @classmethod
@@ -269,12 +228,12 @@ class TestOWExplainPredictions(WidgetTest):
 
         self.widget.graph.set_axis = Mock()
         simulate.combobox_activate_index(self.widget._annot_combo, 3)
-        args = ([[(0, "1"), (1, "1"), (2, "0"), (3, "0"), (4, "0")]],)
+        args = ([[(0, "0"), (1, "0"), (2, "0"), (3, "1"), (4, "1")]],)
         self.widget.graph.set_axis.assert_called_once_with(*args)
 
         self.widget.graph.set_axis.reset_mock()
         simulate.combobox_activate_index(self.widget._annot_combo, 1)
-        args = ([[(0, "2"), (1, "3"), (2, "1"), (3, "5"), (4, "4")]],)
+        args = ([[(0, "4"), (1, "5"), (2, "1"), (3, "3"), (4, "2")]],)
         self.widget.graph.set_axis.assert_called_once_with(*args)
 
         self.send_signal(self.widget.Inputs.data, None)
@@ -294,7 +253,7 @@ class TestOWExplainPredictions(WidgetTest):
         self.widget.graph.set_axis.reset_mock()
         simulate.combobox_activate_index(self.widget._annot_combo, 3)
         self.widget.graph.set_data.assert_called_once()
-        args = ([[(0, "1"), (1, "1"), (2, "0"), (3, "0"), (4, "0")]],)
+        args = ([[(0, "0"), (1, "0"), (2, "0"), (3, "1"), (4, "1")]],)
         self.widget.graph.set_axis.assert_called_once_with(*args)
 
         self.widget.graph.set_data.reset_mock()
